==> MoinLight-0.1.tar.bz2: MoinLight-0.1/moinformat/serialisers/common.py <==
#!/usr/bin/env python

"""
Moin serialiser support.

Copyright (C) 2017, 2018, 2019 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

class Serialiser:

    "General serialisation support."

    format = None # defined by subclasses

    def __init__(self, metadata, serialisers=None):

        """
        Initialise the serialiser with the given 'metadata' and optional
        'serialisers'.
        """

        self.metadata = metadata
        self.serialisers = serialisers

        # Obtain essential metadata.

        self.output = metadata.get_output()
        self.linker = metadata.get_linker()

        # Initialise a callable for use in serialisation.

        self.out = self.output.out

        # Initialisation of any other state.

        self.init()

    def init(self):

        "Initialisation method to be overridden by subclasses."

        pass

    def __repr__(self):
        return "%s(%r)" % (self.__class__.__name__, self.metadata)

    def reset(self):
        self.output.reset()

    def get_serialiser(self, format):

        """
        Return a serialiser for the given 'format'. Return self if no suitable
        serialiser can be obtained.
        """

        cls = self.serialisers.get(format)
        if cls:
            return self.instantiate(cls)
        else:
            return self

    def get_output(self):

        "Return the output as a single Unicode string."

        return self.output.to_string()

    def instantiate(self, cls):

        """
        Instantiate 'cls' and return the result if 'cls' is a different class to
        this instance. Otherwise, return this instance.
        """

        if cls is self.__class__:
            return self
        else:
            return cls(self.metadata, self.serialisers)

def escape_attr(s):

    "Escape XML document attribute."

    return escape_text(s).replace("'", "&apos;").replace('"', "&quot;")

def escape_text(s):

    "Escape XML document text."

    return s.replace("&", "&amp;").replace("<", "&lt;").replace(">", "&gt;")

# vim: tabstop=4 expandtab shiftwidth=4

==> MoinLight-0.2.1.tar.bz2: MoinLight-0.2.1/moinformat/serialisers/common.py <==
#!/usr/bin/env python

"""
Moin serialiser support.

Copyright (C) 2017, 2018, 2019, 2021 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

class Serialiser:

    "General serialisation support."

    input_formats = None    # defined by subclasses
    formats = None          # defined by subclasses

    def __init__(self, metadata, serialisers=None):

        """
        Initialise the serialiser with the given 'metadata' and optional
        'serialisers'.
        """

        self.metadata = metadata
        self.serialisers = serialisers

        # Obtain essential metadata.

        self.output = metadata.get_output()
        self.linker = metadata.get_linker()

        # Initialise a callable for use in serialisation.

        self.out = self.output.out

        # Initialisation of any other state.

        self.init()

    def init(self):

        "Initialisation method to be overridden by subclasses."

        pass

    def __repr__(self):
        return "%s(%r)" % (self.__class__.__name__, self.metadata)

    def reset(self):
        self.output.reset()

    def get_serialiser(self, format):

        """
        Return a serialiser for the given 'format'. Return self if no suitable
        serialiser can be obtained.
        """

        cls = self.serialisers.get(format)
        if cls:
            return self.instantiate(cls)
        else:
            return self

    def get_output(self):

        "Return the output as a single Unicode string."

        return self.output.to_string()

    def instantiate(self, cls):

        """
        Instantiate 'cls' and return the result if 'cls' is a different class to
        this instance. Otherwise, return this instance.
        """

        if cls is self.__class__:
            return self
        else:
            return cls(self.metadata, self.serialisers)

def escape_attr(s):

    "Escape XML document attribute."

    return escape_text(s).replace("'", "&apos;").replace('"', "&quot;")

def escape_text(s):

    "Escape XML document text."

    return s.replace("&", "&amp;").replace("<", "&lt;").replace(">", "&gt;")

# vim: tabstop=4 expandtab shiftwidth=4
